@@ -173,7 +173,8 @@ def _create_project(
 
     team_id = 0
     for team in result.get("results"):
-        if team["organization"] == org_id:
+        # Currently the command line tool does not support user assign org and team, will take default team in default org
+        if team["organization"] == org_id and team["user_role"] == "default":
             team_id = team["id"]
             logger.debug(f"_create_project|team={team}")
             break
@@ -226,7 +227,7 @@ def set_proj(apikey, baseurl, project_id, project_name, file):
         # check if the project exist
         projects_info = get_projects(apikey, baseurl)
         for project_info in projects_info["results"]:
-            if project_info["name"] == project_name:
+            if project_info["name"] == project_name and project_info["provider"] == "upload":
                 project_id = project_info["id"]
 
         # not existing project
