@@ -126,7 +126,7 @@ def scan_sourcecode(folderpath, scantistoken, baseurl):
         os.path.split(os.path.dirname(os.path.abspath(__file__)))[0], "scantist-bom-detect.jar"
     )   
     
-    logger.info("Generating dependency tree in boom detect...")
+    logger.info("Generating dependency tree in bom detect...")
     cmd = (
         "java -jar -Xmx1024m %s "
         "-repo_name %s "
