@@ -57,7 +57,7 @@ def get_scan_summary(scan_id, apikey, baseurl):
     scan_vulnerability_count = get_scan_issues_overview(scan_id, apikey, baseurl)
     scan_licenseissue_count = get_scan_license_overview(scan_id, apikey, baseurl)
 
-    print(
+    logger.info(
         f"scan_components_count : {scan_components_count}, scan_vul_components_count : {scan_vul_components_count}\nscan_vulnerability_count : {scan_vulnerability_count}, scan_licenseissue_count : {scan_licenseissue_count}"
     )
 
@@ -78,7 +78,7 @@ def get_scan_issue_detail(baseurl, apikey, scan_issue_id):
 
 
 def get_scan_issue_list(baseurl, apikey, scan_id):
-    api = f"v1/scan/{scan_id}/issues/"
+    api = f"v1/scans/{scan_id}/issues/"
     headers = {
         "Authorization": "Token " + apikey,
         "Content-Type": "application/json; charset=utf-8",
@@ -87,6 +87,7 @@ def get_scan_issue_list(baseurl, apikey, scan_id):
     result = requests.get(url=url, headers=headers)
 
     if result.status_code != 200:
+        logger.debug(f"scan_result|get_scan_issue_list| status_code: {result.status_code} message: {result.text}")
         error_exit(f"Fail to get scan {scan_id} issue list.")
 
-    return result.json()["result"]
+    return result.json()["results"]
